PseudoInputs - LatentLego

Skip to content

# PseudoInputs

### `latent.layers.PseudoInputs`

Creates trainable pseudo inputs (Tomczak 2017) based on input shapes.

#### `__init__(self, n_inputs, name=None, activation='relu', initializer=None)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`n_inputs` | `int` | Positive integer, number of pseudo-inputs. | required
`name` | `str` | String indicating the name of the layer. | `None`
`activation` | `Union[str, Callable]` | Activation function to use. | `'relu'`
`initializer` | `Union[str, Callable]` | Initializer for the `kernel` weights matrix. | `None`